ErrorResponseWithProcessedFiles class

Error response that includes any files that were successfully processed before the error occurred.

Implemented types

Constructors

ErrorResponseWithProcessedFiles({List<FileMetadata> processedFiles = const [], required String message, Map<String, dynamic>? data})

Properties

data Map<String, dynamic>?
Additional data related to the error, if any.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message.
final
processedFiles List<FileMetadata>
List of files that were successfully processed before the error occurred.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic json) ErrorResponseWithProcessedFiles