processedFiles property
List of files that were successfully processed before the error occurred.
Implementation
final List<FileMetadata> processedFiles;
List of files that were successfully processed before the error occurred.
final List<FileMetadata> processedFiles;