FileData class

Generic file representation (like Blob/File in JavaScript).

Constructors

FileData(Uint8List bytes, {String? filename, String? contentType})

Properties

bytes Uint8List
The file contents as bytes.
final
contentType String?
Optional MIME type for the file.
final
filename String?
Optional filename for the file.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited