UploadFileMetadata class

Metadata provided when uploading a new file.

Constructors

UploadFileMetadata({String? id, String? name, Map<String, dynamic>? metadata})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
Optional custom ID for the file. If not provided, a UUID will be generated.
final
metadata Map<String, dynamic>?
Custom metadata to associate with the file.
final
name String?
Name to assign to the file. If not provided, the original filename will be used.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited