UploadFilesResponse class

Response containing successfully processed files and error information.

Constructors

UploadFilesResponse({required List<FileMetadata> processedFiles})

Properties

hashCode int
The hash code for this object.
no setterinherited
processedFiles List<FileMetadata>
List of successfully processed files with their metadata.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic json) UploadFilesResponse