nhost_storage_dart
library
Classes
-
FileData
-
Generic file representation (like Blob/File in JavaScript).
-
FileMetadata
-
The fields of this class can be used to fetch the file's contents (id),
as well as populate the headers of an HttpResponse if you were to serve
this file to a client.
-
ImageCornerRadius
-
The corner radius applied to an image.
-
ImageTransform
-
Instructs the backend on how to transform a stored image.
-
NhostStorageClient
-
The Nhost storage service.
-
PresignedUrl
-
-
UploadFileMetadata
-
Metadata provided when uploading a new file.
-
UploadFilesResponse
-
Response containing successfully processed files and error information.